@@ -334,7 +334,7 @@ class App(object):
                 middleware(rq)
             res = self.routing(rq)
             if not isinstance(res, Response):
-                res = Response(unicode(res), content_type='text/plain')
+                res = Response(unicode(res), content_type='text/html')
             for middleware in self.response_middlewares:
                 middleware(rq, res)
         except Response, e:
